unit MainUnit;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.ExtCtrls;

type
  TForm1 = class(TForm)
    Panel1: TPanel;
    LogMemo: TMemo;
    TestButton: TButton;
    procedure TestButtonClick(Sender: TObject);
  protected
    procedure ReportStatus(Status: LongWord);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;



implementation

{$R *.dfm}

uses
  AIOUSB;

procedure TForm1.ReportStatus(Status: LongWord);
begin
  if Status = ERROR_SUCCESS then
    LogMemo.Lines.Add('OK!')
  else
    LogMemo.Lines.Add('Error ' + IntToStr(Status) + '.')
  ;
  LogMemo.Lines.Add('');
end;

procedure TForm1.TestButtonClick(Sender: TObject);
var
  DeviceIndex, Status, PID, NomSize, MedDIOData, BytesTransferred: LongWord;
  Nom: AnsiString;
  ReadClockHz, WriteClockHz: Double;
  DIOBuf: array of Word;
  I: Integer;
  OutMask, TristateMask: Byte;

begin
  LogMemo.Lines.Clear;

  DeviceIndex := ResolveDeviceIndex(diFirst);
  if DeviceIndex >= 32 then begin
    LogMemo.Lines.Add('No device found with diFirst, exiting.');
    Exit;
  end;

  NomSize := MAX_PATH;
  SetLength(Nom, NomSize);
  LogMemo.Lines.Add('QueryDeviceInfo');
  Status := QueryDeviceInfo(DeviceIndex, @PID, @NomSize, @Nom[1], nil, nil);
  if Status = ERROR_SUCCESS then begin
    SetLength(Nom, NomSize);
    LogMemo.Lines.Add('OK: [' + IntToStr(DeviceIndex) + '] = ' + IntToHex(PID, 4) + ': ' + Nom);
    if PID <> $800E then begin
      LogMemo.Lines.Add('Expecting 800E: USB-DO16A, exiting.');
      Exit;
    end;
  end
  else begin
    LogMemo.Lines.Add('Error ' + IntToStr(Status));
  end;
  LogMemo.Lines.Add('');

  OutMask := $8;
  MedDIOData := $FFFFFFFF;
  TristateMask := $0;
  DIO_ConfigureEx(DeviceIndex, @OutMask, @MedDIOData, @TristateMask);

  ReadClockHz := 0; //External or "off"
  WriteClockHz := $10000;
  LogMemo.Lines.Add('DIO_StreamSetClocks');
  ReportStatus(DIO_StreamSetClocks(DeviceIndex, ReadClockHz, WriteClockHz));

  SetLength(DIOBuf, $10000);
  for I := 0 to High(DIOBuf) do
    DIOBuf[I] := I
  ;

  BytesTransferred := 0;
  LogMemo.Lines.Add('DIO_StreamOpen');
  ReportStatus(DIO_StreamOpen(DeviceIndex, False));
  LogMemo.Lines.Add('DIO_StreamFrame');
  ReportStatus(DIO_StreamFrame(DeviceIndex, Length(DIOBuf), @DIOBuf[0], BytesTransferred));
  LogMemo.Lines.Add('DIO_StreamClose');
  ReportStatus(DIO_StreamClose(DeviceIndex));
end;

end.
